smartcard.sw.SWExceptions.ExecutionErrorException

# ``smartcard`.`sw`.`SWExceptions`.`ExecutionErrorException``

exception documentation

`class ExecutionErrorException(SWException):`

View In Hierarchy

Raised when an execution error is detected from sw1, sw2. Examples of execution error: sw1=64 or sw=65 (ISO7816-4).

Method | `__init__` | Undocumented

Inherited from `SWException`:

Method | `__str__` | Undocumented
Instance Variable | `data` | response apdu sw1
Instance Variable | `message` | response apdu data
Instance Variable | `sw1` | response apdu sw2
Instance Variable | `sw2` | Undocumented

def __init__(self, data, sw1, sw2, message=''):
overrides `smartcard.sw.SWExceptions.SWException.__init__`

Undocumented